<?php namespace EscapeWork\Manager\News\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\News\Repositories\News\NewsRepository;
use EscapeWork\Manager\News\Repositories\NewsCategory\NewsCategoryRepository;
use EscapeWork\Manager\News\Models\News;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class NewsController extends ManagerController
{

    public function __construct(NewsRepository $news, NewsCategoryRepository $newsCategory)
    {
        $this->news         = $news;
        $this->newsCategory = $newsCategory;

        # filters
        $this->enableDefaultFilters('news');
    }

    public function index()
    {
        $view               = View::make(Config::get('manager-news::views.news.index'));
        $view->notices      = $this->news->filterAndPaginate(Input::all());
        $view->newsCategory = $this->newsCategory;

        return $view;
    }

    /**
    * Show the form for creating a new resource.
    *
    * @return Response
    */
    public function create()
    {
        $view = View::make(Config::get('manager-news::views.news.form'));

        $this->news->fill(Input::old());

        $view->news         = $this->news;
        $view->newsCategory = $this->newsCategory->get();
        $view->edit = false;

        return $view;
    }

    /**
    * Store a newly created resource in storage.
    *
    * @return Response
    */
    public function store()
    {
        $this->news->fill(Input::all());

        if (! $this->news->validate()) {
            return Redirect::route('manager.noticias.create')
                        ->withInput()
                        ->with('errors', News::$messages );
        }

        $this->news->save();

        return Redirect::route('manager.noticias.index')->with('message', 'A notícia <strong>' . $this->news->title . '</strong> foi inserida com sucesso!');
    }

    /**
    * Show the form for editing the specified resource.
    *
    * @return Response
    */
    public function edit($id)
    {
        $this->news = $this->news->findOrFail($id);

        Msg::setInfo('Editando a noticia <strong>' . $this->news->title . '</strong>');

        $view                = View::make(Config::get('manager-news::views.news.form'));
        $view->news          = $this->news;
        $view->newsCategory  = $this->newsCategory->all();
        $view->edit = true;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function update($id)
    {
        $this->news = $this->news->findOrFail($id);
        $this->news->fill(Input::all());

        if (! $this->news->validate()) {
            return Redirect::route('manager.noticias.edit', array($this->news->id))
                    ->withInput()
                    ->with('errors', News::$messages);
        }

        $this->news->save();

        return Redirect::route('manager.noticias.index')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi editada com sucesso!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return Response
     */
    public function destroy($id)
    {
        $this->news = $this->news->findOrFail($id);
        $this->news->delete();

        return Redirect::route('manager.noticias.index')
                ->with('message', 'A notícia <strong>'.$this->news->title.'</strong> foi excluída com sucesso!');
    }

    /**
     * Atualizando se a noticia está ativa ou não
     */
    public function updateActive($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->active = Input::get('active');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    /**
     * Atualizando se a noticia é destaque ou não
     */
    public function updateFeatured($id)
    {
        if (! $this->news = $this->news->find($id)) {
            return Response::json(array(
                'error' => 'Noticia não encontrada'
            ));
        }

        $this->news->featured = Input::get('featured');
        $this->news->save();

        return Response::json(array(
            'message' => 'A noticia foi atualizada com sucesso'
        ));
    }

    /**
     * RSS de noticias
     */
    public function rss()
    {
        $view       = View::make(Config::get('manager-news::views.news.rss'));
        $view->news = $this->news->getLastNews(15);

        $response = Response::make($view->render());
        $response->header('Content-Type', 'text/xml; charset=utf-8');

        return $response;
    }
}
