<?php namespace EscapeWork\Manager\News\Providers;

use EscapeWork\Manager\News\Commands\ConfigureCommand;
use Illuminate\Support\ServiceProvider;

class ManagerNewsServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        $this->package('escapework/manager-news', 'manager-news', realpath(__DIR__ . '/../../../../'));

        include_once(__DIR__ . '/../../../../routes.php');
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerCommands();
        $this->bindRepositories();
    }

    protected function bindRepositories()
    {
        $this->app->bind('EscapeWork\Manager\News\Repositories\News\NewsRepository', 'EscapeWork\Manager\News\Repositories\News\EloquentNewsRepository');
        $this->app->bind('EscapeWork\Manager\News\Repositories\NewsCategory\NewsCategoryRepository', 'EscapeWork\Manager\News\Repositories\NewsCategory\EloquentNewsCategoryRepository');
    }

    protected function registerCommands()
    {
        $this->app['command.manager.news.configure'] = $this->app->share(function($app)
        {
            return new ConfigureCommand;
        });

        $this->commands('command.manager.news.configure');
    }

    public function provides()
    {
        return array('command.manager.news.configure');
    }

}
